# libpythonpro_zero
Study purposes

suportada versao 3 de python

Para instalar:
'''console
python3 -m venv .venv
windows:
.venv\scripts\activate
pip install -r requirements-dev.txt
'''

Para conferir qualidade do codigo:
'''console
flake8
''''
